==> seedsui-react-2.5.7.tgz: package/es/Dragrefresh/Dragrefresh.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Notice from './../Notice';
import Instance from './instance.js';
import ImgLazy from './../ImgLazy';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var Dragrefresh = (_temp = _class = function (_Component) {
  _inherits(Dragrefresh, _Component);

  function Dragrefresh(props) {
    _classCallCheck(this, Dragrefresh);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      if (prevProps.hasMore === _this.props.hasMore) return;
      // 刷新完成则设置刷新
      _this.setPagination(prevProps.hasMore, _this.props.hasMore);
    };

    _this.init = function () {
      var onScroll = _this.props.onScroll;

      var instance = new Instance({
        threshold: _this.props.threshold,
        end: _this.props.end,
        endRefresh: _this.props.endRefresh,
        moveTimeout: _this.props.moveTimeout,
        container: _this.$el,
        onScroll: onScroll,
        onTopRefresh: _this.onTopRefresh, // 头部刷新,加载第一页
        onBottomRefresh: _this.onBottomRefresh, // 底部刷新,加载下一页
        // 构建实体
        topContainer: _this.$elTopBox,
        // 实体交互
        duration: 150,
        onPull: function onPull(e) {
          var topContainer = e.topContainer;
          topContainer.style.height = e.touches.currentPosY + 'px';
          var topIcon = topContainer.querySelector('.df-pull-icon');
          var topCaption = topContainer.querySelector('.df-pull-caption');
          if (!e.isLoading) {
            if (e.touches.currentPosY >= e.params.threshold) {
              if (topIcon) topIcon.classList.add('df-pull-icon-down');
              if (topCaption) topCaption.innerHTML = window._seeds_lang['release'] || '释放立即刷新';
            } else {
              if (topIcon) topIcon.classList.remove('df-pull-icon-down');
              if (topCaption) topCaption.innerHTML = window._seeds_lang['pull_down'] || '下拉可以刷新';
            }
          }
        },
        onShowTop: function onShowTop(e) {
          var topContainer = e.topContainer;
          var topIcon = topContainer.querySelector('.df-pull-icon');
          var topCaption = topContainer.querySelector('.df-pull-caption');
          topContainer.style.height = e.params.threshold + 'px';
          if (topIcon) topIcon.classList.remove('df-pull-icon-down');
          if (topIcon) topIcon.classList.add('df-pull-icon-loading');
          if (topCaption) topCaption.innerHTML = window._seeds_lang['refreshing'] || '正在刷新...';
        },
        onHideTop: function onHideTop(e) {
          var topContainer = e.topContainer;
          topContainer.style.height = '0';
        },
        onTopHid: function onTopHid(e) {
          var topContainer = e.topContainer;
          var topIcon = topContainer.querySelector('.df-pull-icon');
          if (topIcon) topIcon.classList.remove('df-pull-icon-down');
          if (topIcon) topIcon.classList.remove('df-pull-icon-loading');
        }
      });
      _this.instance = instance;
    };

    _this.onTopRefresh = function () {
      _this.props.onTopRefresh();
    };

    _this.onBottomRefresh = function () {
      if (!_this.props.onBottomRefresh) return;
      var hasMore = _this.props.hasMore;

      if (hasMore !== 0 && hasMore !== -1 && hasMore !== 404) {
        _this.props.onBottomRefresh();
      } else {
        if (_this.instance) _this.instance.isLoading = false; // 暂无数据时, 设置为可刷新
      }
    };

    _this.lazyLoad = function () {
      if (!_this.$el) return;
      if (_this.timeout) window.clearTimeout(_this.timeout);
      _this.timeout = setTimeout(function () {
        if (_this.lazy) {
          _this.lazy.load();
        } else {
          _this.lazy = new ImgLazy({
            overflowContainer: _this.$el
          });
          _this.lazy.load();
        }
      }, 500);
    };

    _this.setPagination = function (prevHasMore, hasMore) {
      // 如果还没有初始化完成,则会再轮询调用一下
      if (!_this.instance) {
        setTimeout(function () {
          _this.setPagination(prevHasMore, hasMore);
        }, 100);
        return;
      }
      console.log('hasMore: \u7531' + prevHasMore + '\u53D8\u6210' + hasMore);
      // 无数据时不允许触发刷新
      if (_this.props.showNoData && hasMore === 404) {
        _this.instance.detach();
      } else if (_this.props.showNoData && prevHasMore === 404 && hasMore !== 404) {
        _this.instance.attach();
      }
      // 刷新完成, 需收起头
      if (hasMore !== -2) {
        _this.instance.hideTop();
      }
      // 设置为可刷新
      _this.instance.isLoading = false;
      // 刷新完成, 还有数据
      if (hasMore === 1) {
        // 如果还有数据，并且如果没有滚动条，则继续加载
        if (!_this.instance.hasScroll()) {
          console.log('还有数据,但没有滚动条,继续加载...');
          _this.instance.bottomRefresh();
        }
      }
      // 懒加载
      if (_this.props.lazyLoad) _this.lazyLoad();
    };

    return _this;
  }

  Dragrefresh.prototype.componentDidMount = function componentDidMount() {
    this.init();
    this.setPagination(undefined, this.props.hasMore);
  };
  // 实例化

  // 头部刷新

  // 底部刷新

  // 懒人加载

  // 控制刷新


  Dragrefresh.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        className = _props.className,
        onTopRefresh = _props.onTopRefresh,
        onBottomRefresh = _props.onBottomRefresh,
        showNoData = _props.showNoData,
        hasMore = _props.hasMore,
        noDataParams = _props.noDataParams,
        bottomLoadingCaption = _props.bottomLoadingCaption,
        bottomNoDataCaption = _props.bottomNoDataCaption,
        bottomErrorCaption = _props.bottomErrorCaption,
        onClickBottomError = _props.onClickBottomError;

    return React.createElement(
      'div',
      { ref: function ref(el) {
          _this2.$el = el;
        }, className: 'container' + (className ? ' ' + className : ''), style: style },
      onTopRefresh && React.createElement(
        'div',
        { ref: function ref(el) {
            _this2.$elTopBox = el;
          }, className: 'SID-Dragrefresh-TopContainer df-pull' },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement('div', { className: 'df-pull-icon' }),
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            window._seeds_lang['pull_down'] || '下拉可以刷新'
          )
        )
      ),
      this.props.children,
      onBottomRefresh && (hasMore === 1 || hasMore === -2) && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-BottomContainer df-pull', style: { height: '50px' } },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement('div', { className: 'df-pull-icon df-pull-icon-loading' }),
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomLoadingCaption
          )
        )
      ),
      onBottomRefresh && hasMore === 0 && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-NoDataContainer df-pull', style: { height: '50px' } },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomNoDataCaption
          )
        )
      ),
      onBottomRefresh && hasMore === -1 && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-ErrorContainer df-pull', style: { height: '50px' }, onClick: onClickBottomError },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomErrorCaption
          )
        )
      ),
      hasMore === 404 && showNoData && React.createElement(Notice, _extends({ caption: '暂无数据' }, noDataParams))
    );
  };

  return Dragrefresh;
}(Component), _class.defaultProps = {
  showNoData: true,
  bottomLoadingCaption: window._seeds_lang['loading'] || '正在加载...',
  bottomNoDataCaption: window._seeds_lang['no_more_data'] || '没有更多数据了',
  bottomErrorCaption: window._seeds_lang['refreshing_failed'] || '加载失败, 请稍后再试'
}, _temp);
export { Dragrefresh as default };
Dragrefresh.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,

  threshold: PropTypes.number, // 头部下拉的触发位置
  end: PropTypes.number, // 头部下拉的结束位置
  endRefresh: PropTypes.bool, // 滑动到指位置后自动刷新
  moveTimeout: PropTypes.number, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
  onTopRefresh: PropTypes.func,
  onTopComplete: PropTypes.func,
  onBottomRefresh: PropTypes.func,
  onBottomComplete: PropTypes.func,

  children: PropTypes.node,
  hasMore: PropTypes.number, // hasMore: 0.无更多数据 1.数据加载完成 404.一条数据都没有 -1. 加载错误 -2. 重置状态,为了后面可以更新DOM

  showNoData: PropTypes.bool, // 是否允许暂无数据
  noDataParams: PropTypes.object,

  lazyLoad: PropTypes.bool,

  onScroll: PropTypes.func, // 滚动事件

  // 底部加载中
  bottomLoadingCaption: PropTypes.string,
  // 底部加载完成
  bottomNoDataCaption: PropTypes.string,
  // 底部加载错误
  bottomErrorCaption: PropTypes.string,
  onClickBottomError: PropTypes.func
} : {};

==> seedsui-react-2.6.2.tgz: package/es/Dragrefresh/Dragrefresh.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Notice from './../Notice';
import Instance from './instance.js';
import ImgLazy from './../ImgLazy';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var Dragrefresh = (_temp = _class = function (_Component) {
  _inherits(Dragrefresh, _Component);

  function Dragrefresh(props) {
    _classCallCheck(this, Dragrefresh);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      if (prevProps.hasMore === _this.props.hasMore) return;
      // 刷新完成则设置刷新
      _this.setPagination(prevProps.hasMore, _this.props.hasMore);
    };

    _this.init = function () {
      var onScroll = _this.props.onScroll;

      var instance = new Instance({
        threshold: _this.props.threshold,
        end: _this.props.end,
        endRefresh: _this.props.endRefresh,
        moveTimeout: _this.props.moveTimeout,
        container: _this.$el,
        onScroll: onScroll,
        onTopRefresh: _this.onTopRefresh, // 头部刷新,加载第一页
        onBottomRefresh: _this.onBottomRefresh, // 底部刷新,加载下一页
        // 构建实体
        topContainer: _this.$elTopBox,
        // 实体交互
        duration: 150,
        onPull: function onPull(e) {
          var topContainer = e.topContainer;
          topContainer.style.height = e.touches.currentPosY + 'px';
          var topIcon = topContainer.querySelector('.df-pull-icon');
          var topCaption = topContainer.querySelector('.df-pull-caption');
          if (!e.isLoading) {
            if (e.touches.currentPosY >= e.params.threshold) {
              if (topIcon) topIcon.classList.add('df-pull-icon-down');
              if (topCaption) topCaption.innerHTML = window._seeds_lang['release'] || '释放立即刷新';
            } else {
              if (topIcon) topIcon.classList.remove('df-pull-icon-down');
              if (topCaption) topCaption.innerHTML = window._seeds_lang['pull_down'] || '下拉可以刷新';
            }
          }
        },
        onShowTop: function onShowTop(e) {
          var topContainer = e.topContainer;
          var topIcon = topContainer.querySelector('.df-pull-icon');
          var topCaption = topContainer.querySelector('.df-pull-caption');
          topContainer.style.height = e.params.threshold + 'px';
          if (topIcon) topIcon.classList.remove('df-pull-icon-down');
          if (topIcon) topIcon.classList.add('df-pull-icon-loading');
          if (topCaption) topCaption.innerHTML = window._seeds_lang['refreshing'] || '正在刷新...';
        },
        onHideTop: function onHideTop(e) {
          var topContainer = e.topContainer;
          topContainer.style.height = '0';
        },
        onTopHid: function onTopHid(e) {
          var topContainer = e.topContainer;
          var topIcon = topContainer.querySelector('.df-pull-icon');
          if (topIcon) topIcon.classList.remove('df-pull-icon-down');
          if (topIcon) topIcon.classList.remove('df-pull-icon-loading');
        }
      });
      _this.instance = instance;
    };

    _this.onTopRefresh = function () {
      _this.props.onTopRefresh();
    };

    _this.onBottomRefresh = function () {
      if (!_this.props.onBottomRefresh) return;
      var hasMore = _this.props.hasMore;

      if (hasMore !== 0 && hasMore !== -1 && hasMore !== 404) {
        _this.props.onBottomRefresh();
      } else {
        if (_this.instance) _this.instance.isLoading = false; // 暂无数据时, 设置为可刷新
      }
    };

    _this.lazyLoad = function () {
      if (!_this.$el) return;
      if (_this.timeout) window.clearTimeout(_this.timeout);
      _this.timeout = setTimeout(function () {
        if (_this.lazy) {
          _this.lazy.load();
        } else {
          _this.lazy = new ImgLazy({
            overflowContainer: _this.$el
          });
          _this.lazy.load();
        }
      }, 500);
    };

    _this.setPagination = function (prevHasMore, hasMore) {
      // 如果还没有初始化完成,则会再轮询调用一下
      if (!_this.instance) {
        setTimeout(function () {
          _this.setPagination(prevHasMore, hasMore);
        }, 100);
        return;
      }
      console.log('hasMore: \u7531' + prevHasMore + '\u53D8\u6210' + hasMore);
      // 无数据时不允许触发刷新
      if (_this.props.showNotice && hasMore === 404) {
        _this.instance.detach();
      } else if (_this.props.showNotice && prevHasMore === 404 && hasMore !== 404) {
        _this.instance.attach();
      }
      // 刷新完成, 需收起头
      if (hasMore !== -2) {
        _this.instance.hideTop();
      }
      // 设置为可刷新
      _this.instance.isLoading = false;
      // 刷新完成, 还有数据
      if (hasMore === 1) {
        // 如果还有数据，并且如果没有滚动条，则继续加载
        if (!_this.instance.hasScroll()) {
          console.log('还有数据,但没有滚动条,继续加载...');
          _this.instance.bottomRefresh();
        }
      }
      // 懒加载
      if (_this.props.lazyLoad) _this.lazyLoad();
    };

    return _this;
  }

  Dragrefresh.prototype.componentDidMount = function componentDidMount() {
    this.init();
    this.setPagination(undefined, this.props.hasMore);
  };
  // 实例化

  // 头部刷新

  // 底部刷新

  // 懒人加载

  // 控制刷新


  Dragrefresh.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        className = _props.className,
        onTopRefresh = _props.onTopRefresh,
        onBottomRefresh = _props.onBottomRefresh,
        showNotice = _props.showNotice,
        hasMore = _props.hasMore,
        noticeProps = _props.noticeProps,
        bottomLoadingCaption = _props.bottomLoadingCaption,
        bottomNoDataCaption = _props.bottomNoDataCaption,
        bottomErrorCaption = _props.bottomErrorCaption,
        onClickBottomError = _props.onClickBottomError;

    return React.createElement(
      'div',
      { ref: function ref(el) {
          _this2.$el = el;
        }, className: 'container' + (className ? ' ' + className : ''), style: style },
      onTopRefresh && React.createElement(
        'div',
        { ref: function ref(el) {
            _this2.$elTopBox = el;
          }, className: 'SID-Dragrefresh-TopContainer df-pull' },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement('div', { className: 'df-pull-icon' }),
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            window._seeds_lang['pull_down'] || '下拉可以刷新'
          )
        )
      ),
      this.props.children,
      onBottomRefresh && (hasMore === 1 || hasMore === -2) && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-BottomContainer df-pull', style: { height: '50px' } },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement('div', { className: 'df-pull-icon df-pull-icon-loading' }),
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomLoadingCaption
          )
        )
      ),
      onBottomRefresh && hasMore === 0 && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-NoDataContainer df-pull', style: { height: '50px' } },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomNoDataCaption
          )
        )
      ),
      onBottomRefresh && hasMore === -1 && React.createElement(
        'div',
        { className: 'SID-Dragrefresh-ErrorContainer df-pull', style: { height: '50px' }, onClick: onClickBottomError },
        React.createElement(
          'div',
          { className: 'df-pull-box' },
          React.createElement(
            'div',
            { className: 'df-pull-caption' },
            bottomErrorCaption
          )
        )
      ),
      hasMore === 404 && showNotice && React.createElement(Notice, _extends({ caption: '暂无数据' }, noticeProps))
    );
  };

  return Dragrefresh;
}(Component), _class.defaultProps = {
  showNotice: true,
  bottomLoadingCaption: window._seeds_lang['loading'] || '正在加载...',
  bottomNoDataCaption: window._seeds_lang['no_more_data'] || '没有更多数据了',
  bottomErrorCaption: window._seeds_lang['refreshing_failed'] || '加载失败, 请稍后再试'
}, _temp);
export { Dragrefresh as default };
Dragrefresh.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,

  threshold: PropTypes.number, // 头部下拉的触发位置
  end: PropTypes.number, // 头部下拉的结束位置
  endRefresh: PropTypes.bool, // 滑动到指位置后自动刷新
  moveTimeout: PropTypes.number, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
  onTopRefresh: PropTypes.func,
  onTopComplete: PropTypes.func,
  onBottomRefresh: PropTypes.func,
  onBottomComplete: PropTypes.func,

  children: PropTypes.node,
  hasMore: PropTypes.number, // hasMore: 0.无更多数据 1.数据加载完成 404.一条数据都没有 -1. 加载错误 -2. 重置状态,为了后面可以更新DOM

  showNotice: PropTypes.bool, // 是否允许暂无数据
  noticeProps: PropTypes.object,

  lazyLoad: PropTypes.bool,

  onScroll: PropTypes.func, // 滚动事件

  // 底部加载中
  bottomLoadingCaption: PropTypes.string,
  // 底部加载完成
  bottomNoDataCaption: PropTypes.string,
  // 底部加载错误
  bottomErrorCaption: PropTypes.string,
  onClickBottomError: PropTypes.func
} : {};
